@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import warnings
 
 import numpy as np
@@ -6,9 +8,20 @@ from packaging.version import parse as parse_version
 from dask.utils import derived_from
 
 _np_version = parse_version(np.__version__)
-_numpy_122 = _np_version >= parse_version("1.22.0")
-_numpy_123 = _np_version >= parse_version("1.23.0")
-_numpy_124 = _np_version >= parse_version("1.24.0")
+NUMPY_GE_122 = _np_version.release >= (1, 22)
+NUMPY_GE_123 = _np_version.release >= (1, 23)
+NUMPY_GE_124 = _np_version.release >= (1, 24)
+NUMPY_GE_125 = _np_version.release >= (1, 25)
+NUMPY_GE_200 = _np_version.release >= (2, 0)
+
+
+if NUMPY_GE_200:
+    from numpy.exceptions import AxisError, ComplexWarning  # noqa: F401
+    from numpy.lib.array_utils import normalize_axis_index, normalize_axis_tuple
+else:
+    from numpy import AxisError, ComplexWarning  # noqa: F401
+    from numpy.core.numeric import normalize_axis_index  # type: ignore[attr-defined]
+    from numpy.core.numeric import normalize_axis_tuple  # type: ignore[attr-defined]
 
 
 # Taken from scikit-learn:
@@ -132,10 +145,8 @@ class _Recurser:
 # https://github.com/numpy/numpy/blob/d9b1e32cb8ef90d6b4a47853241db2a28146a57d/numpy/core/numeric.py#L1336-L1405
 @derived_from(np)
 def moveaxis(a, source, destination):
-    source = np.core.numeric.normalize_axis_tuple(source, a.ndim, "source")
-    destination = np.core.numeric.normalize_axis_tuple(
-        destination, a.ndim, "destination"
-    )
+    source = normalize_axis_tuple(source, a.ndim, "source")
+    destination = normalize_axis_tuple(destination, a.ndim, "destination")
     if len(source) != len(destination):
         raise ValueError(
             "`source` and `destination` arguments must have "
@@ -155,7 +166,7 @@ def moveaxis(a, source, destination):
 # https://github.com/numpy/numpy/blob/v1.17.0/numpy/core/numeric.py#L1107-L1204
 def rollaxis(a, axis, start=0):
     n = a.ndim
-    axis = np.core.numeric.normalize_axis_index(axis, n)
+    axis = normalize_axis_index(axis, n)
     if start < 0:
         start += n
     msg = "'%s' arg requires %d <= %s < %d, but %d was passed in"
@@ -174,7 +185,7 @@ def rollaxis(a, axis, start=0):
 
 # kwarg is renamed in numpy 1.22.0
 def percentile(a, q, method="linear"):
-    if _numpy_122:
+    if NUMPY_GE_122:
         return np.percentile(a, q, method=method)
     else:
         return np.percentile(a, q, interpolation=method)
