@@ -1,15 +1,35 @@
 from __future__ import annotations
 
 import copyreg
+import warnings
 
 import pandas as pd
+from packaging.version import Version
 
 try:
     import pyarrow as pa
+
+    pa_version = pa.__version__
+    if Version(pa_version) < Version("14.0.1"):
+        try:
+            import pyarrow_hotfix  # noqa: F401
+
+            warnings.warn(
+                "Minimal version of pyarrow will soon be increased to 14.0.1. "
+                f"You are using {pa_version}. Please consider upgrading.",
+                FutureWarning,
+            )
+        except ImportError:
+            warnings.warn(
+                f"You are using pyarrow version {pa_version} which is "
+                "known to be insecure. See https://www.cve.org/CVERecord?id=CVE-2023-47248 "
+                "for further details. Please upgrade to pyarrow>=14.0.1 "
+                "or install pyarrow-hotfix to patch your current version."
+            )
 except ImportError:
     pa = None
 
-from dask.dataframe._compat import PANDAS_GT_150, PANDAS_GT_200
+from dask.dataframe._compat import PANDAS_GE_150, PANDAS_GE_200
 
 # Pickling of pyarrow arrays is effectively broken - pickling a slice of an
 # array ends up pickling the entire backing array.
@@ -39,8 +59,8 @@ def reduce_arrowextensionarray(x):
 # `pandas=2` includes efficient serialization of `pyarrow`-backed extension arrays.
 # See https://github.com/pandas-dev/pandas/pull/49078 for details.
 # We only need to backport efficient serialization for `pandas<2`.
-if pa is not None and not PANDAS_GT_200:
-    if PANDAS_GT_150:
+if pa is not None and not PANDAS_GE_200:
+    if PANDAS_GE_150:
         # Applies to all `pyarrow`-backed extension arrays (e.g. `string[pyarrow]`, `int64[pyarrow]`)
         for type_ in [pd.arrays.ArrowExtensionArray, pd.arrays.ArrowStringArray]:
             copyreg.dispatch_table[type_] = reduce_arrowextensionarray
